@@ -10,7 +10,9 @@ Mnet::Opts::Set::Silent - Use this module to enable --silent option
 
 =head1 DESCROPTION
 
-This module can be used as a pragma to enable the L<Mnet::Log> --silent option.
+Use this module to enable the --silent option for the Mnet::Log module.
+
+Refer to the Mnet::Log module for more information.
 
 =cut
 
@@ -24,12 +26,6 @@ L<Mnet>
 
 L<Mnet::Log>
 
-L<Mnet::Opts>
-
-L<Mnet::Opts::Cli>
-
-L<Mnet::Opts::Set>
-
 =cut
 
 # normal end of package
